local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus
local action = x.Action
local target = x.Target

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.spells["cat_form,if=!buff.cat_form.up"] = {
	Type = "form",
	ID = 768--[[Cat Form]],
	Buff = 768--[[Cat Form]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["prowl"] = {
	ID = 5215--[[Prowl]],
	Buff = 5215--[[Prowl]],
	BuffUnit = "player",
	Check = function(z)
		return not x.InCombat and x.ShouldTemporaryBuff and x.EnemyDetected
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["wild_charge_cat"] = {
	ID = 49376--[[Wild Charge]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
}

--[[
   ___                             
  / _ \ _ __   ___ _ __   ___ _ __ 
 | | | | '_ \ / _ \ '_ \ / _ \ '__|
 | |_| | |_) |  __/ | | |  __/ |   
  \___/| .__/ \___|_| |_|\___|_|   
       |_|                         ]]

a.spells["rake,if=!ticking|buff.prowl.up"] = {
	ID = 1822--[[Rake]],
	Check = function(z)
		return x.Energy >= action.rake.cost  and (not dot.rake.ticking or buff.prowl.up)
	end,
}

a.spells["dash,if=!buff.cat_form.up"] = {
	ID = 1850--[[Dash]],
	Buff = 768--[[Cat Form]],
	BuffUnit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Moving("player")
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["moonfire_cat,if=talent.lunar_inspiration.enabled&!ticking"] = {
	ID = 155625--[[Moonfire]],
	MyDebuff = 155625--[[Moonfire]],
	BuffUnit = "target",
	Check = function(z)
		return x.InCombat and x.Energy >= action.moonfire.cost and talent.lunar_inspiration.enabled
	end,
}

a.spells["savage_roar,if=!buff.savage_roar.up"] = {
	ID = 52610--[[Savage Roar]],
	Buff = 52610--[[Savage Roar]],
	BuffUnit = "player",
	Check = function(z)
		return x.CP >= 1
	end,
}

a.spells["berserk"] = {
	ID = 106951--[[Berserk]],
	Buff = 106951--[[Berserk]],
	BuffUnit = "player",
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return not talent.incarnation.enabled
	end,
	Continue = true,
}

a.spells["incarnation"] = {
	ID = 102543--[[Incarnation]],
	Buff = 102543--[[Incarnation]],
	BuffUnit = "player",
	Check = function(z)
		return talent.incarnation.enabled
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["tigers_fury"] = {
	ID = 5217--[[Tiger's Fury]],
	Buff = 5217--[[Tiger's Fury]],
	BuffUnit = "player",
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["ashamanes_frenzy"] = {
	ID = 210722--[[Ashamane's Frenzy]],
}

a.spells["regrowth,if=(talent.sabertooth.enabled|buff.predatory_swiftness.up)&talent.bloodtalons.enabled&buff.bloodtalons.down&combo_points=5"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return (talent.sabertooth.enabled or buff.predatory_swiftness.up) and talent.bloodtalons.enabled and buff.bloodtalons.down and x.CP == 5
	end,
}

a.spells["rip,if=combo_points=5"] = {
	ID = 1079--[[Rip]],
	Check = function(z)
		return x.Energy >= action.rip.cost and x.CP == 5
	end,
}

a.spells["thrash_cat,if=!ticking&variable.use_thrash>0"] = {
	ID = 106830--[[Thrash]],
	Override = function(z)
		if x.EnemyDetected and x.Energy >= action.thrash.cost and cooldown.thrash.remains <= 0 and s.MeleeDistance() and not dot.thrash.ticking and x.UseThrash > 0 then
			s.Flash(106830--[[Thrash]], nil, nil, 100)
			return true
		else
			return false
		end
	end,
}

a.spells["shred"] = {
	ID = 5221--[[Shred]],
	Check = function(z)
		return x.Energy >= action.shred.cost
	end,
}

--[[
   ____            _     _                         
  / ___|___   ___ | | __| | _____      ___ __  ___ 
 | |   / _ \ / _ \| |/ _` |/ _ \ \ /\ / / '_ \/ __|
 | |__| (_) | (_) | | (_| | (_) \ V  V /| | | \__ \
  \____\___/ \___/|_|\__,_|\___/ \_/\_/ |_| |_|___/
                                                   ]]

a.spells["prowl,if=buff.incarnation.remains<0.5&buff.jungle_stalker.up"] = {
	ID = 5215--[[Prowl]],
	Buff = 5215--[[Prowl]],
	BuffUnit = "player",
	Check = function(z)
		return buff.incarnation.remains_nogcd < x.MaxGCD and buff.jungle_stalker.up_nogcd
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["berserk,if=energy>=30&(cooldown.tigers_fury.remains>5|buff.tigers_fury.up)"] = {
	ID = 106951--[[Berserk]],
	Buff = 106951--[[Berserk]],
	BuffUnit = "player",
	Check = function(z)
		return x.Energy >= 30 and (cooldown.tigers_fury.remains_nogcd > 5 or buff.tigers_fury.up_nogcd)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["tigers_fury,if=energy.deficit>=60"] = {
	ID = 5217--[[Tiger's Fury]],
	Buff = 5217--[[Tiger's Fury]],
	BuffUnit = "player",
	Check = function(z)
		return x.EnergyDeficit>= 60
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["berserking"] = {
	ID = 26297--[[Berserking]],
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["elunes_guidance,if=combo_points=0&energy>=50"] = {
	ID = 202060--[[Elune's Guidance]],
	Buff = 202060--[[Elune's Guidance]],
	BuffUnit = "player",
	Check = function(z)
		return x.CP == 0 and x.Energy >= 50
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["incarnation,if=energy>=30&(cooldown.tigers_fury.remains>15|buff.tigers_fury.up)"] = {
	ID = 102543--[[Incarnation]],
	Buff = 102543--[[Incarnation]],
	BuffUnit = "player",
	Check = function(z)
		return x.Energy >= 30 and talent.incarnation.enabled and (cooldown.tigers_fury.remains_nogcd > 15 or buff.tigers_fury.up_nogcd)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["potion,name=prolonged_power,if=target.time_to_die<65|(time_to_die<180&(buff.berserk.up|buff.incarnation.up))"] = {
	Type = "item",
	ID = 229206--[[Potion of Prolonged Power]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target") and (target.time_to_die < 65 or (target.time_to_die < 180 and (buff.berserk.up_nogcd or buff.incarnation.up_nogcd)))
	end,
	FlashColor = "Yellow",
}

a.spells["ashamanes_frenzy,if=combo_points>=2&(!talent.bloodtalons.enabled|buff.bloodtalons.up)"] = {
	ID = 210722--[[Ashamane's Frenzy]],
	Check = function(z)
		return x.CP >= 2 and (not talent.bloodtalons.enabled or buff.bloodtalons.up)
	end,
}

,"shadowmeld,if=combo_points<5&energy>=action.rake.cost&dot.rake.pmultiplier<2.1&buff.tigers_fury.up&(buff.bloodtalons.up|!talent.bloodtalons.enabled)&(!talent.incarnation.enabled|cooldown.incarnation.remains>18)&!buff.incarnation.up"

--[[
  ____  _             _        _____                    _   
 / ___|(_)_ __   __ _| | ___  |_   _|_ _ _ __ __ _  ___| |_ 
 \___ \| | '_ \ / _` | |/ _ \   | |/ _` | '__/ _` |/ _ \ __|
  ___) | | | | | (_| | |  __/   | | (_| | | | (_| |  __/ |_ 
 |____/|_|_| |_|\__, |_|\___|   |_|\__,_|_|  \__, |\___|\__|
                |___/                        |___/          ]]

a.spells["rake,if=buff.prowl.up|buff.shadowmeld.up"] = {
	ID = 1822--[[Rake]],
	Check = function(z)
		return x.Energy >= action.rake.cost and (buff.prowl.up or s.Buff(58984--[[Shadowmeld]], "player"))
	end,
}

a.spells["ferocious_bite,target_if=dot.rip.ticking&dot.rip.remains<3&target.time_to_die>10&(target.health.pct<25|talent.sabertooth.enabled)"] = {
	ID = 22568--[[Ferocious Bite]],
	Check = function(z)
		return x.Energy >= action.ferocious_bite.cost and x.CP >= 1 and dot.rip.ticking and dot.rip.remains < 3 and target.time_to_die > 10 and (s.HealthPercent("target") < 25 or talent.sabertooth.enabled)
	end,
}

a.spells["regrowth,if=combo_points=5&buff.predatory_swiftness.up&talent.bloodtalons.enabled&buff.bloodtalons.down&(!buff.incarnation.up|dot.rip.remains<8)"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return x.CP == 5 and buff.predatory_swiftness.up and talent.bloodtalons.enabled and buff.bloodtalons.down and (not buff.incarnation.up or dot.rip.remains < 8)
	end,
}

a.spells["regrowth,if=combo_points>3&talent.bloodtalons.enabled&buff.predatory_swiftness.up&buff.apex_predator.up&buff.incarnation.down"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return x.CP > 3 and talent.sabertooth.enabled and buff.predatory_swiftness.up and buff.apex_predator.up and buff.incarnation.down
	end,
}

a.spells["ferocious_bite,if=buff.apex_predator.up&((combo_points>4&(buff.incarnation.up|talent.moment_of_clarity.enabled))|(talent.bloodtalons.enabled&buff.bloodtalons.up&combo_points>3))"] = {
	ID = 22568--[[Ferocious Bite]],
	Check = function(z)
		return x.Energy >= action.ferocious_bite.cost and buff.apex_predator.up and ((x.CP > 4 and (buff.incarnation.up or talent.moment_of_clarity.enabled)) or (talent.sabertooth.enabled and buff.bloodtalons.up and x.CP > 3))
	end,
}

--[[
  _____ _       _     _                   
 |  ___(_)_ __ (_)___| |__   ___ _ __ ___ 
 | |_  | | '_ \| / __| '_ \ / _ \ '__/ __|
 |  _| | | | | | \__ \ | | |  __/ |  \__ \
 |_|   |_|_| |_|_|___/_| |_|\___|_|  |___/
                                          ]]

a.spells["savage_roar,if=buff.savage_roar.down"] = {
	ID = 52610--[[Savage Roar]],
	Buff = 52610--[[Savage Roar]],
	BuffUnit = "player",
	Check = function(z)
		z.FlashBrightness = s.If(x.Energy < 40, 30, 100)
		return x.CP > 4
	end,
}

a.spells["rip,target_if=!ticking|(remains<=duration*0.3)&(target.health.pct>25&!talent.sabertooth.enabled)|(remains<=duration*0.8&persistent_multiplier>dot.rip.pmultiplier)&target.time_to_die>8"] = {
	ID = 1079--[[Rip]],
	Check = function(z)
		z.FlashBrightness = s.If(x.Energy < action.rip.cost, 30, 100)
		return x.CP > 4 and (not dot.rip.ticking or dot.rip.refreshable and (s.HealthPercent("target") > 25 and not talent.sabertooth.enabled) or (dot.rip.remains <= dot.rip.duration * 0.8 and false--[[&persistent_multiplier>dot.rip.pmultiplier]]) and target.time_to_die > 8)
	end,
}

a.spells["savage_roar,if=buff.savage_roar.remains<12"] = {
	ID = 52610--[[Savage Roar]],
	Buff = 52610--[[Savage Roar]],
	BuffUnit = "player",
	EarlyRefresh = 12,
	Check = function(z)
		z.FlashBrightness = s.If(x.Energy < 40, 30, 100)
		return x.CP > 4
	end,
}

a.spells["maim,if=buff.fiery_red_maimers.up"] = {
	ID = 22570--[[Maim]],
	RequireBuff = 236757--[[Fiery Red Maimers]],
	RequireBuffUnit = "player",
}

a.spells["ferocious_bite,max_energy=1"] = {
	ID = 22568--[[Ferocious Bite]],
	Check = function(z)
		return x.CP > 4 and x.Energy >= action.ferocious_bite.cost
	end,
}

--[[
   ____                           _                 
  / ___| ___ _ __   ___ _ __ __ _| |_ ___  _ __ ___ 
 | |  _ / _ \ '_ \ / _ \ '__/ _` | __/ _ \| '__/ __|
 | |_| |  __/ | | |  __/ | | (_| | || (_) | |  \__ \
  \____|\___|_| |_|\___|_|  \__,_|\__\___/|_|  |___/
                                                    ]]

a.spells["regrowth,if=talent.bloodtalons.enabled&buff.predatory_swiftness.up&buff.bloodtalons.down&combo_points>=2&cooldown.ashamanes_frenzy.remains<gcd"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return talent.sabertooth.enabled and buff.predatory_swiftness.up and buff.bloodtalons.down and x.CP >= 2 and cooldown.ashamanes_frenzy.remains < x.MaxGCD
	end,
}

a.spells["regrowth,if=talent.bloodtalons.enabled&buff.predatory_swiftness.up&buff.bloodtalons.down&combo_points=4&dot.rake.remains<4"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return talent.sabertooth.enabled and buff.predatory_swiftness.up and buff.bloodtalons.down and x.CP == 4 and dot.rake.remains < 4
	end,
}

a.spells["regrowth,if=equipped.ailuro_pouncers&talent.bloodtalons.enabled&(buff.predatory_swiftness.stack>2|(buff.predatory_swiftness.stack>1&dot.rake.remains<3))&buff.bloodtalons.down"] = {
	ID = 8936--[[Regrowth]],
	NoRangeCheck = true,
	Check = function(z)
		return equipped.ailuro_pouncers and talent.bloodtalons.enabled and (buff.predatory_swiftness.stack > 2 and buff.predatory_swiftness.up or (buff.predatory_swiftness.stack > 1 and buff.predatory_swiftness.up and dot.rake.remains < 3)) and buff.bloodtalons.down
	end,
}

a.spells["brutal_slash,if=spell_targets.brutal_slash>desired_targets"] = {
	ID = 202028--[[Brutal Slash]],
	NoRangeCheck = true,
	Melee = true,
	Check = function(z)
		return x.Energy >= action.brutal_slash.cost and x.ActiveEnemies > 2 and talent.brutal_slash.enabled
	end,
	FlashID = {213764--[[Swipe]], 202028--[[Brutal Slash]]},
}

a.spells["thrash_cat,if=refreshable&(spell_targets.thrash_cat>2)"] = {
	ID = 106830--[[Thrash]],
	Override = function(z)
		if x.EnemyDetected and cooldown.thrash.remains <= 0 and s.MeleeDistance() and dot.thrash.refreshable and x.ActiveEnemies > 2 then
			s.Flash(106830--[[Thrash]], nil, nil, s.If(x.Energy < action.thrash.cost, 30, 100))
			return true
		else
			return false
		end
	end,
}

a.spells["thrash_cat,if=spell_targets.thrash_cat>3&equipped.luffa_wrappings&talent.brutal_slash.enabled"] = {
	ID = 106830--[[Thrash]],
	Override = function(z)
		if x.EnemyDetected and cooldown.thrash.remains <= 0 and s.MeleeDistance() and x.ActiveEnemies > 3 and equipped.luffa_wrappings and talent.brutal_slash.enabled then
			s.Flash(106830--[[Thrash]], nil, nil, s.If(x.Energy < action.thrash.cost, 30, 100))
			return true
		else
			return false
		end
	end,
}

a.spells["rake,target_if=!ticking|(!talent.bloodtalons.enabled&remains<duration*0.3)&target.time_to_die>4"] = {
	ID = 1822--[[Rake]],
	Check = function(z)
		z.FlashBrightness = s.If(x.Energy < action.rake.cost, 30, 100)
		return not dot.rake.ticking or (not talent.sabertooth.enabled and dot.rake.refreshable) and target.time_to_die > 4
	end,
}

a.spells["rake,target_if=talent.bloodtalons.enabled&buff.bloodtalons.up&((remains<=7)&persistent_multiplier>dot.rake.pmultiplier*0.85)&target.time_to_die>4"] = {
	ID = 1822--[[Rake]],
	Check = function(z)
		z.FlashBrightness = s.If(x.Energy < action.rake.cost, 30, 100)
		return talent.sabertooth.enabled and buff.bloodtalons.up and ((dot.rake.remains <= 7) --[[and persistent_multiplier > dot.rake.pmultiplier*0.85]]) and target.time_to_die > 4
	end,
}

a.spells["brutal_slash,if=(buff.tigers_fury.up&(raid_event.adds.in>(1+max_charges-charges_fractional)*recharge_time))"] = {
	ID = 202028--[[Brutal Slash]],
	NoRangeCheck = true,
	Melee = true,
	Check = function(z)
		return x.Energy >= action.brutal_slash.cost and talent.brutal_slash.enabled and (buff.tigers_fury.up --[[and (raid_event.adds.in > (1 + max_charges - charges_fractional) * recharge_time)]])
	end,
	FlashID = {213764--[[Swipe]], 202028--[[Brutal Slash]]},
}

a.spells["moonfire_cat,target_if=refreshable"] = {
	ID = 155625--[[Moonfire]],
	MyDebuff = 155625--[[Moonfire]],
	BuffUnit = "target",
	EarlyRefresh = 4.2,
	Check = function(z)
		return x.InCombat and x.Energy >= action.moonfire.cost and talent.lunar_inspiration.enabled
	end,
}

a.spells["thrash_cat,if=refreshable&(variable.use_thrash=2|spell_targets.thrash_cat>1)"] = {
	ID = 106830--[[Thrash]],
	Override = function(z)
		if x.EnemyDetected and cooldown.thrash.remains <= 0 and s.MeleeDistance() and dot.thrash.refreshable and (x.UseThrash == 2 or x.ActiveEnemies > 1) then
			s.Flash(106830--[[Thrash]], nil, nil, s.If(x.Energy < action.thrash.cost, 30, 100))
			return true
		else
			return false
		end
	end,
}

a.spells["thrash_cat,if=refreshable&variable.use_thrash=1&buff.clearcasting.react"] = {
	ID = 106830--[[Thrash]],
	Override = function(z)
		if x.EnemyDetected and cooldown.thrash.remains <= 0 and s.MeleeDistance() and dot.thrash.refreshable and x.UseThrash == 1 and buff.clearcasting.up then
			s.Flash(106830--[[Thrash]], nil, nil, s.If(x.Energy < action.thrash.cost, 30, 100))
			return true
		else
			return false
		end
	end,
}

a.spells["swipe_cat,if=spell_targets.swipe_cat>1"] = {
	ID = 213764--[[Swipe]],
	NoRangeCheck = true,
	Melee = true,
	Check = function(z)
		z.FlashBrightness = s.If(x.Energy < action.swipe.cost, 30, 100)
		return not talent.brutal_slash.enabled and x.ActiveEnemies > 1
	end,
}

a.spells["shred,if=dot.rake.remains>(action.shred.cost+action.rake.cost-energy)%energy.regen|buff.clearcasting.react"] = {
	ID = 5221--[[Shred]],
	Check = function(z)
		return x.Energy >= action.shred.cost and (dot.rake.remains > (action.shred.cost + 35 - x.Energy) / x.EnergyRegen or buff.clearcasting.up)
	end,
}
